# ratelimiteredis

An async ratelimiter using aioredis inspired from [redis-ratelimit project](https://github.com/romantomjak/redis-ratelimit).

## Installation

```bash
python3.7 -m pip install -U ratelimiteredis
```

<!-- ## Usage

```py
import ratelimiteredis
``` -->

## TODO

More flexibility with rates.<br>
An discord.py integration for cooldowns.
